from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from app.routes import todos_router, health_router
from app.db.session import engine
from app.db.base import Base

# Create database tables
Base.metadata.create_all(bind=engine)

app = FastAPI(
    title="Todo API",
    description="A simple Todo application API built with FastAPI",
    version="1.0.0",
    openapi_url="/openapi.json"
)

# Configure CORS
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Include routers
app.include_router(todos_router, prefix="/api/v1")
app.include_router(health_router)

@app.get("/")
def root():
    return {
        "title": "Todo API",
        "description": "A simple Todo application API built with FastAPI",
        "version": "1.0.0",
        "documentation": "/docs",
        "health_check": "/health"
    }